
# Class: NamespacesCollection


A holder for Namespaces objects

URI: [nwb_schema_language:NamespacesCollection](https://w3id.org/p2p_ld/nwb-schema-language/NamespacesCollection)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Namespaces]<entries%200..*-++[NamespacesCollection],[Namespaces])](https://yuml.me/diagram/nofunky;dir:TB/class/[Namespaces]<entries%200..*-++[NamespacesCollection],[Namespaces])

## Attributes


### Own

 * [➞entries](namespacesCollection__entries.md)  <sub>0..\*</sub>
     * Range: [Namespaces](Namespaces.md)
